OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Oppgaver",
    "Personal" : "Personlig",
    "{actor} created calendar {calendar}" : "{actor} opprettet kalenderen {calendar}",
    "You created calendar {calendar}" : "Du opprettet kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} slettet kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettet kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} oppdaterte kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du oppdaterte kalenderen {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} gjenopprettet kalenderen {calendar}",
    "You restored calendar {calendar}" : "Du gjenopprettet kalenderen {calendar}",
    "You shared calendar {calendar} as public link" : "Du delte kalenderen {calendar} som offentlig lenke",
    "You removed public link for calendar {calendar}" : "Du fjernet offentlig lenke for kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med deg",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} opphevde delingen av kalenderen {calendar} med deg",
    "You unshared calendar {calendar} from {user}" : "Du opphevde delingen av kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} opphevde delingen av kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} opphevde delingen av kalenderen {calendar} med seg selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalender {calendar} med gruppe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} opphevde deling av kalenderen {calendar} med gruppe {group}",
    "Untitled event" : "Hendelse uten tittel",
    "{actor} created event {event} in calendar {calendar}" : "{actor} opprettet en hendelse {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du opprettet en hendelse {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettet hendelsen {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettet hendelsen {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} oppdaterte hendelsen {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du oppdaterte hendelsen {event} i kalenderen {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} flyttet hendelsen {event} fra kalenderen {sourceCalendar} til kalenderen {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du flyttet hendelsen {event} fra kalenderen {sourceCalendar} til kalenderen {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} opprettet hendelsen {event} i kalenderen {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du gjenopprettet hendelsen {event} i kalenderen {calendar}",
    "Busy" : "Opptatt",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} opprettet gjøremålet {todo} i listen {calendar}",
    "You created to-do {todo} in list {calendar}" : "Du opprettet gjøremålet {todo} i listen {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} slettet gjøremålet {todo} fra listen {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Du slettet gjøremålet {todo} fra listen {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} oppdaterte gjøremålet {todo} i listen {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Du oppdaterte gjøremålet {todo} i listen {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} ferdigstilte gjøremålet {todo} i listen {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Du ferdigstilte gjøremålet {todo} i listen {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} gjenåpnet gjøremålet {todo} i listen {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Du gjenåpnet gjøremålet {todo} i listen {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} flyttet gjøremålet {todo} fra listen {sourceCalendar} til listen {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du flyttet gjøremålet {todo} fra listen {sourceCalendar} til listen {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalender, kontakter og oppgaver",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ble endret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>hendelse</strong> ble endret",
    "A calendar <strong>to-do</strong> was modified" : "Ett kalender- <strong>gjøremål</strong> ble endret",
    "Contact birthdays" : "Kontakters fødelsdag",
    "Death of %s" : "Død av %s",
    "Untitled calendar" : "Kalender uten tittel",
    "Calendar:" : "Kalender:",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n måned","%n måneder"],
    "_%n day_::_%n days_" : ["%n dag","%n dager"],
    "_%n hour_::_%n hours_" : ["%n time","%n timer"],
    "_%n minute_::_%n minutes_" : ["%n minutt","%n minutter"],
    "%s (in %s)" : "%s (i %s)",
    "%s (%s ago)" : "%s (%s siden)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Beskrivelse: %s",
    "Where: %s" : "Hvor: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Kansellerte: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" har blitt kansellert",
    "Re: %1$s" : "Sv: %1$s",
    "%1$s has accepted your invitation" : "%1$s har godtatt invitasjonen din",
    "%1$s has tentatively accepted your invitation" : "%1$s har foreløpig godtatt invitasjonen din",
    "%1$s has declined your invitation" : "%1$s har avvist invitasjonen din",
    "%1$s has responded to your invitation" : "%1$s har svart på invitasjonen din",
    "Invitation updated: %1$s" : "Invitasjon oppdatert: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s oppdaterte hendelsen \"%2$s\"",
    "Invitation: %1$s" : "Invitasjon: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vil invitere deg til \"%2$s\"",
    "Organizer:" : "Arrangør:",
    "Attendees:" : "Deltakere:",
    "Title:" : "Tittel:",
    "Time:" : "Tid:",
    "Location:" : "Sted:",
    "Link:" : "Lenke:",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "More options …" : "Flere alternativer ...",
    "More options at %s" : "Flere alternativer ved %s",
    "Contacts" : "Kontakter",
    "{actor} created address book {addressbook}" : "{actor} opprettet adresseboken {addressbook}",
    "You created address book {addressbook}" : "Du opprettet adresseboken {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} slettet adresseboken {addressbook}",
    "You deleted address book {addressbook}" : "Du slettet adresseboken {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} oppdaterte adresseboken {addressbook}",
    "You updated address book {addressbook}" : "Du oppdaterte adresseboken {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} delte adresseboken {addressbook} med deg",
    "You shared address book {addressbook} with {user}" : "Du delte adresseboken {addressbook} med {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} delte adresseboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} opphevde deling av adresseboken {addressbook} med deg",
    "You unshared address book {addressbook} from {user}" : "Du opphevde deling av adresseboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} opphevde deling av adresseboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} opphevde deling av adresseboken {addressbook} med seg selv",
    "You shared address book {addressbook} with group {group}" : "Du delte adresseboken {addressbook} med gruppen {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} delte adresseboken {addressbook} med gruppen {group}",
    "You unshared address book {addressbook} from group {group}" : "Du har opphevde deling av adresseboken {addressbook} med gruppen {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} opphevde deling av adresseboken {addressbook} med gruppen {gruppe}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} opprettet kontakten {card} i adresseboken {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Du opprettet kontakten {card} i adresseboken {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} slettet kontakten {card} i adresseboken {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Du slettet kontakten {card} i adresseboken {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} oppdaterte kontakten {card} i adresseboken {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Du oppdaterte kontakten {card} i adresseboken {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressebok</strong> ble endret",
    "Accounts" : "Kontoer",
    "System address book which holds all accounts" : "Systemadressebok som inneholder alle kontoer",
    "File is not updatable: %1$s" : "Filen kan ikke oppdateres: %1$s",
    "Could not write to final file, canceled by hook" : "Kunne ikke skrive til den endelige filen, kansellert av hook",
    "Could not write file contents" : "Kunne ikke skrive filinnhold",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Feil under kopiering av fil til målplassering (kopiert: %1$s, forventet filstørrelse: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Forventet filstørrelse på %1$s, men lest (fra Nextcloud-klienten) og skrev (til Nextcloud-lagring) %2$s. Kan enten være et nettverksproblem på avsendersiden eller et problem med å skrive til lagringen på serversiden.",
    "Could not rename part file to final file, canceled by hook" : "Kunne ikke endre navn på delfilen til endelig fil, kansellert av hook",
    "Could not rename part file to final file" : "Kunne ikke endre navn på delfil til endelig fil",
    "Failed to check file size: %1$s" : "Kunne ikke kontrollere filstørrelsen: %1$s",
    "Could not open file" : "Kunne ikke åpne fil",
    "Encryption not ready: %1$s" : "Kryptering ikke klar: %1$s",
    "Failed to open file: %1$s" : "Kunne ikke åpne filen: %1$s",
    "Failed to unlink: %1$s" : "Kunne ikke fjerne tilknytningen: %1$s",
    "Invalid chunk name" : "Ugyldig bitnavn",
    "Could not rename part file assembled from chunks" : "Kunne ikke gi nytt navn til delfil satt sammen fra biter",
    "Failed to write file contents: %1$s" : "Kunne ikke skrive filinnhold: %1$s",
    "File not found: %1$s" : "Filen ble ikke funnet: %1$s",
    "System is in maintenance mode." : "System i vedlikeholdsmodus.",
    "Upgrade needed" : "Oppgradering er nødvendig",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s må konfigureres til å bruke HTTPS for å kunne bruke CalDAV og CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerer en CalDAV konto",
    "Configures a CardDAV account" : "Konfigurerer en CardDAV konto",
    "Events" : "Hendelser",
    "Untitled task" : "Oppgave uten tittel",
    "Completed on %s" : "Ferdig på %s",
    "Due on %s by %s" : "Forfaller på %s ved %s",
    "Due on %s" : "Forfaller på %s",
    "DAV system address book" : "DAV-systemadressebok",
    "No outstanding DAV system address book sync." : "Ingen utestående DAV-systemadressebok synkronisering.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemadresseboksynkroniseringen har ikke kjørt enda fordi forekomsten har mer enn 1000 brukere, eller fordi det oppstod en feil. Kjør den manuelt ved å kalle \"occ dav: sync-system-addressbook\".",
    "Migrated calendar (%1$s)" : "Migrerte kalenderen (%1$s)",
    "Calendars including events, details and attendees" : "Kalendere inkludert hendelser, detaljer og deltakere",
    "Contacts and groups" : "Kontakter og grupper",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endepunkt",
    "First day" : "Første dag",
    "Last day (inclusive)" : "Siste dag (inklusive)",
    "Short absence status" : "Kort fraværsstatus",
    "Long absence Message" : "Lang fraværsmelding",
    "Save" : "Lagre",
    "Disable absence" : "Deaktiver fravær",
    "Absence saved" : "Fravær lagret",
    "Failed to save your absence settings" : "Lagring av dine fraværsinnstillinger feilet",
    "Absence cleared" : "Fravær fjernet",
    "Failed to clear your absence settings" : "Fjerning av dine fraværsinnstillinger feilet",
    "Time zone:" : "Tidssone:",
    "to" : "til",
    "Delete slot" : "Slett tidsluke",
    "No working hours set" : "Ingen arbeidstid satt",
    "Add slot" : "Legg til tidsrom",
    "Weekdays" : "Ukedager",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Pick a start time for {dayName}" : "Velg et starttidspunkt for {dayName}",
    "Pick a end time for {dayName}" : "Velg et sluttidspunkt for {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Sett brukerstatus automatisk til «Ikke forstyrr» utenfor arbeidstid for å dempe alle varsler.",
    "Failed to load availability" : "Feilet med laste inn arbeidstid",
    "Saved availability" : "Lagret arbeidstid",
    "Failed to save availability" : "Feilet ved lagring av arbeidstid",
    "Availability" : "Arbeidstid",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Hvis du konfigurerer arbeidstiden din, vil andre personer se når du ikke er på kontoret når de bestiller et møte.",
    "Absence" : "Fravær",
    "Configure your next absence period." : "Konfigurer din neste fraværsperiode.",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Send invitasjoner til deltakere",
    "Automatically generate a birthday calendar" : "Lag fødelsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalender lages automatisk av en bakgrunnsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derav vil de ikke være tilgjengelige umiddelbart etter at du har skrudd dem på, men vil vises etter en stund.",
    "Send notifications for events" : "Send varsler om hendelser",
    "Notifications are sent via background jobs, so these must occur often enough." : "Varsler sendes via bakgrunnsjobber, så disse må forekomme ofte nok.",
    "Send reminder notifications to calendar sharees as well" : "Send påminnelsesvarsler til kalenderdelinger også",
    "Reminders are always sent to organizers and attendees." : "Reminders are always sent to organizers and attendees.",
    "Enable notifications for events via push" : "Aktiver varsler for hendelser via push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer også {calendarappstoreopen} Kalender-appen {linkclose}, eller {calendardocopen} knytt datamaskinen og mobilen din for synkronisering ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Vennligst sørg for å sette opp {emailopen}e-postinnstillingene{linkclose} på riktig måte.",
    "There was an error updating your attendance status." : "Det oppsto en feil under oppdateringen av oppmøtestatusen din.",
    "Please contact the organizer directly." : "Ta kontakt med arrangøren direkte.",
    "Are you accepting the invitation?" : "Aksepterer du invitasjonen?",
    "Tentative" : "Foreløpig",
    "Your attendance was updated successfully." : "Deltakelsen din ble oppdatert.",
    "To-dos" : "Gjøremål",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Hvis du konfigurerer arbeidstiden din, vil andre brukere se når du ikke er på kontoret når de bestiller et møte."
},
"nplurals=2; plural=(n != 1);");
